import React from 'react'
import useForm from "./useForm";
import Button from "../Button";
import TextInput from "../TextInput";
import FormField from "./FormField";
import SelectField from "../Select";
import * as yup from 'yup';


export default {
  title: 'Design System/Form',
}

const Template = (args) => {
  const form = useForm(args);
  const {handleFormSubmit} = form;

  return <div style={{width: '360px'}}>
    <FormField form={form} name={'textField'} Component={TextInput} label={'Text field'}
               placeholder={`I'm text field`}/>
    <FormField form={form} name={'selectField'} Component={SelectField} label={'Text field'}
               options={[
                 {value: '123', label: '123'},
                 {value: '456', label: '456'}]}/>
    <Button thin={true} onClick={handleFormSubmit((e, values) => {
      console.log(values)
    })}>Go</Button>
  </div>
}

export const regular = Template.bind({})
regular.args = {
  initialState: {
    textField: '',
    selectField: null
  },
  validator: yup.object().shape({
    selectField: yup
      .string()
      .required('selectField is required'),
    textField: yup
      .string()
      .required('textField is required'),
  })
}
