import React from 'react'
import Grid from './index'
import useTable from './useTable'
import {compareSnapshotAndScreenshot} from '../../testUtils'
import {SELECTION_TYPE} from './Selection'
import ByolIcon from '../../assets/svgs/byol.svg'
import ExternalTableFilters from '../ExternalTableFilters'
import ButtonText from "../ButtonText";
import MenuPopover from "../MenuPopover";

export default {
  title: 'Design System/Grid',
  component: Grid
}
const columns = [
  {
    Header: 'Volume Name',
    accessor: 'volumeName',
    sortable: true,
    renderCell: (cellValue) => {
      return <span><ByolIcon style={{width: '15px', paddingRight: '10px'}}/><span>{cellValue}</span></span>
    }
  },
  {
    Header: 'SVM Name',
    accessor: 'svmName',
    sortable: true,
    filterOptions: [
      {value: 'awdawd 1', label: 'awdawd 1'},
      {value: 'awdawd 2', label: 'awdawd 2'},
      {value: 'awdawd 3', label: 'awdawd 3'},
    ],
    info: <div>Im info <br/>tooltip</div>
  },
  {
    Header: 'Volume Size',
    accessor: 'volumeSize',
    filterOptions: [
      {value: '462TB', label: '462TB'}
    ]
  },
  {
    Header: 'Used Size',
    accessor: 'UsedSize',
    renderCell: (cellValue) => {
      return <ButtonText>{cellValue}</ButtonText>
    }
  },
  {
    Header: 'Snapshot used size',
    accessor: 'snapshotUsedSize'
  },
  {
    Header: 'Cold Data (Estimated)',
    accessor: 'coldData',
    info: <span>asd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asd</span>
  }

]

const sampleRow = (a, index) => ({
  volumeName: 'asdddd ' + index,
  svmName: 'awdawd ' + index,
  volumeSize: '462TB',
  coldData: '50TB | 70%',
  snapshotUsedSize: 'Available for Tiering',
  UsedSize: '25TB'
})
const data = Array(10).fill({}).map(sampleRow)
const bigData = Array(150).fill({}).map(sampleRow)

const Template = ({columns: rawColumns, data, pageSize, disableAutoSizeColumns, className, ...rest}) => {
  const tableProps = useTable({
    rows: data,
    columns: rawColumns,
    isSorting: true,
    pageSize,
    ...rest
  })
  return <Grid disableAutoSizeColumns={disableAutoSizeColumns} className={className} {...tableProps} />
}

export const regular = Template.bind({})
regular.args = {
  data,
  columns
}

export const pagination = Template.bind({})

pagination.args = {
  data: bigData,
  columns
}

//TODO: The following 2 stories are temporarily commented to allow tests run, until the bug is fixed

// export const multipleSelection = Template.bind({})
// multipleSelection.args = {
//   data,
//   columns,
//   selectionType: SELECTION_TYPE.MULTIPLE,
//   defaultSelectedRows: ['1', '3']
// }
//
// multipleSelection.parameters = {
//   async puppeteerTest(page) {
//     const element = await page.$('.Suc-cell')
//     await element.click() // select Row
//     await page.waitForTimeout(1000)
//     await compareSnapshotAndScreenshot(page)
//   }
// }
//
// export const singleSelection = Template.bind({})
//
// singleSelection.args = {
//   data,
//   columns,
//   selectionType: SELECTION_TYPE.SINGULAR,
//   defaultSelectedRows: ['3']
// }
//
// singleSelection.parameters = {
//   async puppeteerTest(page) {
//     const element = await page.$('.Suc-cell')
//     await element.click() // select Row
//     await page.waitForTimeout(1000)
//     await compareSnapshotAndScreenshot(page)
//   }
// }

const ExternalFilteredTemplate = ({columns: rawColumns, data, pageSize, disableAutoSizeColumns, className, ...rest}) => {
  const tableProps = useTable({
    rows: data,
    columns: rawColumns,
    isSorting: true,
    pageSize,
    // adding this as an example:
    // initialSortState: {
    //   column: '1',
    //   sortOrder: 'desc'
    // },
    // initialFilterState: {
    //   columns: {
    //     2: {
    //       activeCount: 1,
    //       values: { '462TB': true },
    //       valuesArray: [true]
    //     }
    //   }
    // },
    ...rest
  })

  return <div>
    <ExternalTableFilters {...tableProps}/>
    <Grid isExternalFilter={true} disableAutoSizeColumns={disableAutoSizeColumns}
          className={className} {...tableProps} />
  </div>
}

export const externalFilter = ExternalFilteredTemplate.bind({})

externalFilter.args = {
  data,
  columns
}

const skeletonRow = ({
  volumeName: 'asdddd ',
  svmName: 'awdawd ',
  volumeSize: '462TB',
  coldData: '50TB | 70%',
  snapshotUsedSize: 'Available for Tiering',
  UsedSize: '25TB',
  cellProps: {
    skeleton: true
  }
})
const disabledRow = {
  volumeName: 'asdddd ',
  svmName: 'awdawd ',
  volumeSize: '462TB',
  coldData: '50TB | 70%',
  snapshotUsedSize: 'Available for Tiering',
  UsedSize: '25TB',
  disableSelection: true,
  cellProps: {}
}

export const RowFeatures = Template.bind({})

RowFeatures.args = {
  data: [skeletonRow, disabledRow],
  selectionType: SELECTION_TYPE.SINGULAR,
  columns
}

export const WithMenu = Template.bind({})

const columnsWithMenu = columns.concat([
  {
    Header: '', accessor: 'menu', sortable: false, renderCell: () => {
      return <MenuPopover
        triggerVariant="table"
        menuItems={["Action A", "Action B"]}
        appendToBody
      />
    }
  }
]);

//if using MenuPopover in a table, should add "appendToBody" prop
const dataWithMenu = data.map(a => ({
  ...a,
  menu: ""
}))

WithMenu.args = {
  data: dataWithMenu,
  columns: columnsWithMenu
}

WithMenu.parameters = {
  async puppeteerTest(page) {
    const element = await page.$('.Suc-menu-trigger')
    await element.click() // open menu
    await page.waitForTimeout(1000)
    await compareSnapshotAndScreenshot(page)
  }
}

const TemplateHorizontalScroll = ({columns: rawColumns, data, pageSize, disableAutoSizeColumns, className, ...rest}) => {
  const tableProps = useTable({
    rows: data,
    columns: rawColumns,
    isSorting: true,
    pageSize,
    ...rest
  })
  return <div style={{height: '600px'}}><Grid disableAutoSizeColumns={disableAutoSizeColumns}
                                              className={className} {...tableProps} horizontalScroll={true}/>
  </div>
}

const horizontalScrollColumns = [
  {
    Header: 'Volume Name',
    accessor: 'volumeName',
    sortable: true,
    width: '350px',
  },
  {
    Header: 'SVM Name',
    accessor: 'svmName',
    sortable: true,
    width: '350px',
    filterOptions: [
      {value: 'awdawd 1', label: 'awdawd 1'},
      {value: 'awdawd 2', label: 'awdawd 2'},
      {value: 'awdawd 3', label: 'awdawd 3'},
    ],
    info: <div>Im info <br/>tooltip</div>
  },
  {
    Header: 'Volume Size',
    accessor: 'volumeSize',
    width: '150px',
    filterOptions: [
      {value: '462TB', label: '462TB'}
    ]
  },
  {
    Header: 'Used Size',
    width: '150px',
    accessor: 'UsedSize',
    renderCell: (cellValue) => {
      return <ButtonText>{cellValue}</ButtonText>
    }
  },
  {
    Header: 'Snapshot used size',
    accessor: 'snapshotUsedSize',
    width: '350px',
  },
  {
    Header: 'Cold Data (Estimated)',
    width: '350px',
    accessor: 'coldData',
    info: <span>asd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asdasd asd</span>
  },
  {
    Header: 'SVM Name',
    accessor: 'svmName',
    width: '350px',
    sortable: true,
    filterOptions: [
      {value: 'awdawd 1', label: 'awdawd 1'},
      {value: 'awdawd 2', label: 'awdawd 2'},
      {value: 'awdawd 3', label: 'awdawd 3'},
    ],
    info: <div>Im info <br/>tooltip</div>
  },
  {
    Header: 'Volume Size',
    width: '350px',
    accessor: 'volumeSize',
    filterOptions: [
      {value: '462TB', label: '462TB'}
    ]
  },
  {
    Header: 'Used Size',
    width: '350px',
    accessor: 'UsedSize',
    renderCell: (cellValue) => {
      return <ButtonText>{cellValue}</ButtonText>
    }
  },
  {
    Header: 'Snapshot used size',
    width: '150px',
    accessor: 'snapshotUsedSize'
  },
  {
    Header: 'Cold Data (Estimated)',
    accessor: 'coldData',
    width: '150px',
  }

]
export const horizontalScroll = TemplateHorizontalScroll.bind({})
horizontalScroll.args = {
  data: bigData,
  columns: horizontalScrollColumns
}

export const horizontalScrollStickColumnBothSize = TemplateHorizontalScroll.bind({})
horizontalScrollStickColumnBothSize.args = {
  data: bigData,
  columns: [{
    Header: 'Cold Data',
    accessor: 'coldData',
    width: '150px',
    sticky: true,
  }, ...horizontalScrollColumns, {
    Header: 'Cold Data',
    accessor: 'coldData',
    width: '60px',
    sticky: true,
  }]
}

export const horizontalScrollStickColumnOnlyLeft = TemplateHorizontalScroll.bind({})
horizontalScrollStickColumnOnlyLeft.args = {
  data: bigData,
  columns: [{
    Header: 'Cold Data',
    accessor: 'coldData',
    width: '150px',
    sticky: true,
  }, ...horizontalScrollColumns]
}

